Learn R Programming

nanoarrow (version 0.7.0-3)

infer_nanoarrow_ptype: Infer an R vector prototype

Description

Resolves the default to value to use in convert_array() and convert_array_stream(). The default conversions are:

Usage

infer_nanoarrow_ptype(x)

Value

An R vector of zero size describing the target into which the array should be materialized.

Arguments

x

A nanoarrow_schema, nanoarrow_array, or nanoarrow_array_stream.

Details

Additional conversions are possible by specifying an explicit value for to. For details of each conversion, see convert_array().

Examples

Run this code
infer_nanoarrow_ptype(as_nanoarrow_array(1:10))

Run the code above in your browser using DataLab